commit:     5a408e1b46a80e022a01da0750de92dce46dd104
Author:     Anthony G. Basile <blueness <AT> gentoo <DOT> org>
AuthorDate: Sun Aug  3 11:40:07 2014 +0000
Commit:     Anthony G. Basile <blueness <AT> gentoo <DOT> org>
CommitDate: Sun Aug  3 11:40:07 2014 +0000
URL:        
http://git.overlays.gentoo.org/gitweb/?p=proj/elfix.git;a=commit;h=5a408e1b

pocs/link-graph: rename 'maps' -> 'graph'

---
 pocs/link-graph/__pycache__/link_graph.cpython-33.pyc    | Bin 0 -> 6588 bytes
 pocs/{link-maps/link_map.py => link-graph/link_graph.py} |   6 +++---
 .../link_map_test => link-graph/link_graph_test}         |   8 ++++----
 3 files changed, 7 insertions(+), 7 deletions(-)

diff --git a/pocs/link-graph/__pycache__/link_graph.cpython-33.pyc 
b/pocs/link-graph/__pycache__/link_graph.cpython-33.pyc
new file mode 100644
index 0000000..400f22e
Binary files /dev/null and 
b/pocs/link-graph/__pycache__/link_graph.cpython-33.pyc differ

diff --git a/pocs/link-maps/link_map_test b/pocs/link-graph/link_graph_test
similarity index 92%
rename from pocs/link-maps/link_map_test
rename to pocs/link-graph/link_graph_test
index 9a1af8e..619b88f 100755
--- a/pocs/link-maps/link_map_test
+++ b/pocs/link-graph/link_graph_test
@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 #
-#    link_map_test: this file is part of the elfix package
+#    link_graph_test: this file is part of the elfix package
 #    Copyright (C) 2011  Anthony G. Basile
 #
 #    This program is free software: you can redistribute it and/or modify
@@ -18,7 +18,7 @@
 
 import os
 import sys
-from link_map import LinkMap
+from link_graph import LinkGraph
 
 def main():
 
@@ -28,8 +28,8 @@ def main():
         print('RUN AS ROOT: cannot read all flags')
         sys.exit(0)
 
-    link_map = LinkMap()
-    ( object_linkings, object_reverse_linkings, library2soname, soname2library 
) = link_map.get_maps()
+    link_graph = LinkGraph()
+    ( object_linkings, object_reverse_linkings, library2soname, soname2library 
) = link_graph.get_graph()
 
     layout = "{0:<30} => {1:<30}"
 

Reply via email to
diff --git a/pocs/link-maps/link_map.py b/pocs/link-graph/link_graph.py
similarity index 98%
rename from pocs/link-maps/link_map.py
rename to pocs/link-graph/link_graph.py
index 5b0e822..030aba8 100755
--- a/pocs/link-maps/link_map.py
+++ b/pocs/link-graph/link_graph.py
@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 #
 #    LinkMap.py: this file is part of the elfix package
 #    Copyright (C) 2011  Anthony G. Basile
 #
 #    This program is free software: you can redistribute it and/or modify
@@ -19,7 +19,7 @@
 import re
 import portage
 
-class LinkMap:
+class LinkGraph:
 
     def __init__(self):
         """ Put all the NEEDED.ELF.2 files for all installed packages
@@ -178,7 +178,7 @@ class LinkMap:
         return object_reverse_linkings
 
 
-    def get_maps(self):
+    def get_graph(self):
         """ Generate the full forward and reverse links using the above 
functions """
 
@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 #
-#    LinkMap.py: this file is part of the elfix package
+#    LinkGraph.py: this file is part of the elfix package
 #    Copyright (C) 2011  Anthony G. Basile
 #
         # After get_object_needed() and get_soname_needed(), both 
object_linkings and
